@@ -1,7 +1,6 @@
 use std::collections::HashMap;
 
 use abscissa_core::{Command, Options, Runnable};
-use anomaly::BoxError;
 
 use ibc::ics24_host::identifier::ChainId;
 use ibc_relayer::{
@@ -61,7 +60,9 @@ pub struct KeysListOptions {
     pub chain_config: ChainConfig,
 }
 
-pub fn list_keys(config: ChainConfig) -> Result<Vec<(String, KeyEntry)>, BoxError> {
+pub fn list_keys(
+    config: ChainConfig,
+) -> Result<Vec<(String, KeyEntry)>, Box<dyn std::error::Error>> {
     let keyring = KeyRing::new(Store::Test, &config.account_prefix, &config.id)?;
     let keys = keyring.keys()?;
     Ok(keys)
