@@ -1,6 +1,6 @@
 use std::io;
 
-use abscissa_core::{Component, FrameworkError};
+use abscissa_core::{Component, FrameworkError, FrameworkErrorKind};
 use tracing_subscriber::{
     fmt::{
         format::{DefaultFields, Format, Full, Json, JsonFields},
@@ -14,6 +14,8 @@ use tracing_subscriber::{
 
 use ibc_relayer::config::GlobalConfig;
 
+use crate::config::Error;
+
 /// Custom types to simplify the `Tracing` definition below
 type JsonFormatter = TracingFormatter<JsonFields, Format<Json, SystemTime>, StdWriter>;
 type PrettyFormatter = TracingFormatter<DefaultFields, Format<Full, SystemTime>, StdWriter>;
@@ -34,7 +36,7 @@ impl JsonTracing {
     /// Creates a new [`Tracing`] component
     #[allow(trivial_casts)]
     pub fn new(cfg: GlobalConfig) -> Result<Self, FrameworkError> {
-        let filter = build_tracing_filter(cfg.log_level);
+        let filter = build_tracing_filter(cfg.log_level.to_string())?;
         // Note: JSON formatter is un-affected by ANSI 'color' option. Set to 'false'.
         let use_color = false;
 
@@ -65,7 +67,7 @@ impl PrettyTracing {
     /// Creates a new [`Tracing`] component
     #[allow(trivial_casts)]
     pub fn new(cfg: GlobalConfig) -> Result<Self, FrameworkError> {
-        let filter = build_tracing_filter(cfg.log_level);
+        let filter = build_tracing_filter(cfg.log_level.to_string())?;
 
         // Construct a tracing subscriber with the supplied filter and enable reloading.
         let builder = FmtSubscriber::builder()
@@ -92,12 +94,31 @@ fn enable_ansi() -> bool {
     atty::is(atty::Stream::Stdout) && atty::is(atty::Stream::Stderr)
 }
 
-fn build_tracing_filter(log_level: String) -> String {
+/// Builds a tracing filter based on the input `log_level`.
+/// Enables tracing exclusively for the relayer crates.
+/// Returns error if the filter failed to build.
+fn build_tracing_filter(log_level: String) -> Result<EnvFilter, FrameworkError> {
     let target_crates = ["ibc_relayer", "ibc_relayer_cli"];
 
-    target_crates
+    // SAFETY: unwrap() below works as long as `target_crates` is not empty.
+    let directive_raw = target_crates
         .iter()
         .map(|&c| format!("{}={}", c, log_level))
         .reduce(|a, b| format!("{},{}", a, b))
-        .unwrap()
+        .unwrap();
+
+    // Build the filter directive
+    match EnvFilter::try_new(directive_raw.clone()) {
+        Ok(out) => Ok(out),
+        Err(e) => {
+            eprintln!(
+                "Unable to initialize Hermes from filter directive {:?}: {}",
+                directive_raw, e
+            );
+            let our_err = Error::invalid_log_level(log_level, e);
+            Err(FrameworkErrorKind::ConfigError
+                .context(format!("{}", our_err))
+                .into())
+        }
+    }
 }
